FluentZeroBuilder

Struct FluentZeroBuilder 

pub struct FluentZeroBuilder { /* private fields */ }
A builder to configure and generate the static cache code for fluent-zero.

Implementations

Source

impl FluentZeroBuilder

pub fn new<P: AsRef<Path>>(locales_dir_path: P) -> Self

Creates a new builder pointing to the directory containing locale subdirectories.

Arguments
  • locales_dir_path - Relative path to the folder containing locale subdirectories.
pub fn export_charset<P: AsRef<Path>>(self, dest: P) -> Self

Opt-in to exporting a deterministic text file containing all unique characters used across all .ftl files in this crate and its dependencies.

Dependency Aggregation: This natively aggregates characters from dependencies using Cargo’s standard IPC. No metadata scraping or tree walking is required.

pub fn generate(self)

Consumes the builder, parses the Fluent files, aggregates IPC variables, and generates the Rust static cache code.

Panics

Panics if the OUT_DIR environment variable is not set, or if critical IO file system operations fail during compilation.