pub struct FluentZeroBuilder { /* private fields */ }Expand description
A builder to configure and generate the static cache code for fluent-zero.
Implementations
Sourceimpl FluentZeroBuilder
impl FluentZeroBuilder
Sourcepub fn new<P: AsRef<Path>>(locales_dir_path: P) -> Self
pub fn new<P: AsRef<Path>>(locales_dir_path: P) -> Self
Creates a new builder pointing to the directory containing locale subdirectories.
Sourcepub fn export_charset<P: AsRef<Path>>(self, dest: P) -> Self
pub fn export_charset<P: AsRef<Path>>(self, dest: P) -> Self
Opt-in to exporting a deterministic text file containing all unique
characters used across all .ftl files. This is highly recommended
for font subsetting in WASM/Game GUI environments.